@@ -78,7 +78,7 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     b = " = "
 
     if c_componente[1] == None:
-      c = "\\cdots"
+      c = "?"
     else:
       c = sympy.latex(Redondear(c_componente[1]))
     
